//importing React and some of the hooks from react
import React, { useState, useEffect } from 'react';
//importing json() function from D3
import { json } from 'd3';
//importing feature() and mesh() from TopoJSON
import { feature, mesh } from 'topojson';

//the file containing the geographic information of the states in the USA in .json format
const jsonUrl = 'https://unpkg.com/us-atlas@3.0.0/states-10m.json';

// *New* drug overdose mortalities by state 2020
const csvUrl = 'https://gist.githubusercontent.com/1godfrey/1c678af2823216b0f948930f3ec705bb/raw/c276f6081f28de09d9d3dca934ccb072f49600fb/data-table-2020.csv';

//useData() in React is an local store to share data across components based on hooks
export const useData = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    // Load CSV data
    d3.csv(csvUrl).then(csvData => {
      // Group CSV data by state
      const csvDataByState = d3.nest()
        .key(d => d.State)
        .object(csvData);

      // Load JSON data
      d3.json(jsonUrl).then(topology => {
        // Extract states object from topology
        const { states } = topology.objects;

        // Get array of state names
        const stateNames = Object.keys(states);

        // Add CSV data to states object
        stateNames.forEach(stateName => {
          const stateData = csvDataByState[stateName];
          if (stateData) {
            states[stateName].data = stateData;
          }
        });

        // Set data state
        setData({
          land: feature(topology, states),
          interiors: mesh(topology, states, (a, b) => a !== b)
        });
      });
    });
  }, []);

  return data;
};
